@@ -1,5 +1,6 @@
 use git_cliff_core::commit::{
 	Commit,
+	Range,
 	Signature,
 };
 use git_cliff_core::config::{
@@ -21,9 +22,11 @@ use std::fmt::Write;
 fn generate_changelog() -> Result<()> {
 	let changelog_config = ChangelogConfig {
 		header:         Some(String::from("this is a changelog")),
-		body:           Some(String::from(
+		body:           String::from(
 			r#"
 ## Release {{ version }} - <DATE>
+
+{{ commit_range.from }}..{{ commit_range.to }}
 {% for group, commits in commits | group_by(attribute="group") %}
 ### {{ group }}
 {% for commit in commits %}
@@ -37,23 +40,24 @@ fn generate_changelog() -> Result<()> {
 {% endif -%}
 {% endfor -%}
 {% endfor %}"#,
-		)),
+		),
 		footer:         Some(String::from("eoc - end of changelog")),
-		trim:           None,
-		render_always:  None,
-		postprocessors: None,
+		trim:           true,
+		render_always:  false,
+		postprocessors: [].to_vec(),
 		output:         None,
 	};
 	let git_config = GitConfig {
-		conventional_commits:     Some(true),
-		filter_unconventional:    Some(true),
-		split_commits:            Some(false),
-		commit_preprocessors:     Some(vec![TextProcessor {
+		conventional_commits:     true,
+		require_conventional:     false,
+		filter_unconventional:    true,
+		split_commits:            false,
+		commit_preprocessors:     vec![TextProcessor {
 			pattern:         Regex::new(r"\(fixes (#[1-9]+)\)").unwrap(),
 			replace:         Some(String::from("[closes Issue${1}]")),
 			replace_command: None,
-		}]),
-		commit_parsers:           Some(vec![
+		}],
+		commit_parsers:           vec![
 			CommitParser {
 				sha:           Some(String::from("coffee")),
 				message:       None,
@@ -114,17 +118,18 @@ fn generate_changelog() -> Result<()> {
 				field:         Some(String::from("author.name")),
 				pattern:       Regex::new("John Doe").ok(),
 			},
-		]),
-		protect_breaking_commits: None,
-		filter_commits:           Some(true),
+		],
+		protect_breaking_commits: false,
+		filter_commits:           true,
 		tag_pattern:              None,
 		skip_tags:                None,
 		ignore_tags:              None,
 		count_tags:               None,
-		use_branch_tags:          None,
-		topo_order:               None,
-		sort_commits:             None,
-		link_parsers:             Some(vec![
+		use_branch_tags:          false,
+		topo_order:               false,
+		topo_order_commits:       true,
+		sort_commits:             String::from("oldest"),
+		link_parsers:             vec![
 			LinkParser {
 				pattern: Regex::new("#(\\d+)").unwrap(),
 				href:    String::from("https://github.com/$1"),
@@ -135,8 +140,9 @@ fn generate_changelog() -> Result<()> {
 				href:    String::from("https://github.com/$1"),
 				text:    Some(String::from("$1")),
 			},
-		]),
+		],
 		limit_commits:            None,
+		recurse_submodules:       None,
 	};
 
 	let mut commit_with_author = Commit::new(
@@ -150,13 +156,25 @@ fn generate_changelog() -> Result<()> {
 		timestamp: 0x0,
 	};
 
-	let releases = vec![
-		Release {
-			version:   Some(String::from("v2.0.0")),
-			message: None,
-            extra: None,
-			commits:   vec![
+	let release_v1_commits = vec![
+		Commit::new(
+			String::from("0bc123"),
+			String::from("feat: add cool features"),
+		),
+		Commit::new(String::from("0werty"), String::from("fix: fix stuff")),
+		Commit::new(String::from("0w3rty"), String::from("fix: fix more stuff")),
+		Commit::new(String::from("0jkl12"), String::from("chore: do nothing")),
+	]
+	.into_iter()
+	.filter_map(|c| c.into_conventional().ok())
+	.collect::<Vec<Commit>>();
 
+	let release_v1_commit_range = Range::new(
+		release_v1_commits.first().unwrap(),
+		release_v1_commits.last().unwrap(),
+	);
+
+	let release_v2_commits = vec![
 				Commit::new(
 					String::from("000abc"),
 					String::from("Add unconventional commit"),
@@ -195,11 +213,25 @@ fn generate_changelog() -> Result<()> {
 			]
 			.iter()
 			.filter_map(|c| c.process(&git_config).ok())
-			.collect::<Vec<Commit>>(),
+			.collect::<Vec<Commit>>();
+
+	let release_v2_commit_range = Range::new(
+		release_v2_commits.first().unwrap(),
+		release_v2_commits.last().unwrap(),
+	);
+
+	let releases = vec![
+		Release {
+			version: Some(String::from("v2.0.0")),
+			message: None,
+			extra: None,
+			commits: release_v2_commits,
+			commit_range: Some(release_v2_commit_range),
 			commit_id: None,
 			timestamp: 0,
-			previous:  None,
+			previous: None,
 			repository: Some(String::from("/root/repo")),
+			submodule_commits: HashMap::new(),
 			#[cfg(feature = "github")]
 			github: git_cliff_core::remote::RemoteReleaseMetadata {
 				contributors: vec![],
@@ -218,31 +250,16 @@ fn generate_changelog() -> Result<()> {
 			},
 		},
 		Release {
-			version:   Some(String::from("v1.0.0")),
+			version: Some(String::from("v1.0.0")),
 			message: None,
-            extra: None,
-			commits:   vec![
-				Commit::new(
-					String::from("0bc123"),
-					String::from("feat: add cool features"),
-				),
-				Commit::new(String::from("0werty"), String::from("fix: fix stuff")),
-				Commit::new(
-					String::from("0w3rty"),
-					String::from("fix: fix more stuff"),
-				),
-				Commit::new(
-					String::from("0jkl12"),
-					String::from("chore: do nothing"),
-				),
-			]
-			.into_iter()
-			.filter_map(|c| c.into_conventional().ok())
-			.collect::<Vec<Commit>>(),
+			extra: None,
+			commits: release_v1_commits,
+			commit_range: Some(release_v1_commit_range),
 			commit_id: None,
 			timestamp: 0,
-			previous:  None,
+			previous: None,
 			repository: Some(String::from("/root/repo")),
+			submodule_commits: HashMap::new(),
 			#[cfg(feature = "github")]
 			github: git_cliff_core::remote::RemoteReleaseMetadata {
 				contributors: vec![],
@@ -263,7 +280,7 @@ fn generate_changelog() -> Result<()> {
 	];
 
 	let out = &mut String::new();
-	let template = Template::new("test", changelog_config.body.unwrap(), false)?;
+	let template = Template::new("test", changelog_config.body, false)?;
 
 	writeln!(out, "{}", changelog_config.header.unwrap()).unwrap();
 	let text_processors = [TextProcessor {
@@ -290,6 +307,8 @@ fn generate_changelog() -> Result<()> {
 
 ## Release v2.0.0 - 2023
 
+abc123..hjdfas32
+
 ### docs
 - *(cool)* testing author filtering
 
@@ -309,6 +328,8 @@ fn generate_changelog() -> Result<()> {
 
 ## Release v1.0.0 - 2023
 
+0bc123..0jkl12
+
 ### chore
 - do nothing
 
